#include <gio/gio.h>

#if defined (__ELF__) && ( __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 6))
# define SECTION __attribute__ ((section (".gresource.libxfce4ui"), aligned (8)))
#else
# define SECTION
#endif

#ifdef _MSC_VER
static const SECTION union { const guint8 data[3722]; const double alignment; void * const ptr;}  libxfce4ui_resource_data = { {
  0107, 0126, 0141, 0162, 0151, 0141, 0156, 0164, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 
  0030, 0000, 0000, 0000, 0254, 0000, 0000, 0000, 0000, 0000, 0000, 0050, 0005, 0000, 0000, 0000, 
  0000, 0000, 0000, 0000, 0002, 0000, 0000, 0000, 0002, 0000, 0000, 0000, 0003, 0000, 0000, 0000, 
  0005, 0000, 0000, 0000, 0113, 0120, 0220, 0013, 0001, 0000, 0000, 0000, 0254, 0000, 0000, 0000, 
  0004, 0000, 0114, 0000, 0260, 0000, 0000, 0000, 0264, 0000, 0000, 0000, 0324, 0265, 0002, 0000, 
  0377, 0377, 0377, 0377, 0264, 0000, 0000, 0000, 0001, 0000, 0114, 0000, 0270, 0000, 0000, 0000, 
  0274, 0000, 0000, 0000, 0236, 0123, 0076, 0042, 0003, 0000, 0000, 0000, 0274, 0000, 0000, 0000, 
  0013, 0000, 0114, 0000, 0310, 0000, 0000, 0000, 0314, 0000, 0000, 0000, 0240, 0124, 0352, 0031, 
  0000, 0000, 0000, 0000, 0314, 0000, 0000, 0000, 0005, 0000, 0114, 0000, 0324, 0000, 0000, 0000, 
  0330, 0000, 0000, 0000, 0301, 0307, 0017, 0171, 0002, 0000, 0000, 0000, 0330, 0000, 0000, 0000, 
  0027, 0000, 0166, 0000, 0360, 0000, 0000, 0000, 0211, 0016, 0000, 0000, 0157, 0162, 0147, 0057, 
  0003, 0000, 0000, 0000, 0057, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 0154, 0151, 0142, 0170, 
  0146, 0143, 0145, 0064, 0165, 0151, 0057, 0000, 0004, 0000, 0000, 0000, 0170, 0146, 0143, 0145, 
  0057, 0000, 0000, 0000, 0002, 0000, 0000, 0000, 0154, 0151, 0142, 0170, 0146, 0143, 0145, 0064, 
  0165, 0151, 0055, 0144, 0151, 0141, 0154, 0157, 0147, 0055, 0165, 0151, 0056, 0165, 0151, 0000, 
  0211, 0015, 0000, 0000, 0000, 0000, 0000, 0000, 0074, 0077, 0170, 0155, 0154, 0040, 0166, 0145, 
  0162, 0163, 0151, 0157, 0156, 0075, 0042, 0061, 0056, 0060, 0042, 0040, 0145, 0156, 0143, 0157, 
  0144, 0151, 0156, 0147, 0075, 0042, 0125, 0124, 0106, 0055, 0070, 0042, 0077, 0076, 0012, 0074, 
  0041, 0055, 0055, 0040, 0107, 0145, 0156, 0145, 0162, 0141, 0164, 0145, 0144, 0040, 0167, 0151, 
  0164, 0150, 0040, 0147, 0154, 0141, 0144, 0145, 0040, 0063, 0056, 0061, 0070, 0056, 0063, 0040, 
  0055, 0055, 0076, 0012, 0074, 0151, 0156, 0164, 0145, 0162, 0146, 0141, 0143, 0145, 0076, 0012, 
  0040, 0040, 0074, 0162, 0145, 0161, 0165, 0151, 0162, 0145, 0163, 0040, 0154, 0151, 0142, 0075, 
  0042, 0147, 0164, 0153, 0053, 0042, 0040, 0166, 0145, 0162, 0163, 0151, 0157, 0156, 0075, 0042, 
  0063, 0056, 0061, 0062, 0042, 0057, 0076, 0012, 0040, 0040, 0074, 0157, 0142, 0152, 0145, 0143, 
  0164, 0040, 0143, 0154, 0141, 0163, 0163, 0075, 0042, 0107, 0164, 0153, 0115, 0145, 0163, 0163, 
  0141, 0147, 0145, 0104, 0151, 0141, 0154, 0157, 0147, 0042, 0040, 0151, 0144, 0075, 0042, 0170, 
  0146, 0143, 0145, 0064, 0165, 0151, 0055, 0144, 0151, 0141, 0154, 0157, 0147, 0042, 0076, 0012, 
  0040, 0040, 0040, 0040, 0074, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 
  0155, 0145, 0075, 0042, 0143, 0141, 0156, 0137, 0146, 0157, 0143, 0165, 0163, 0042, 0076, 0106, 
  0141, 0154, 0163, 0145, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0076, 0012, 
  0040, 0040, 0040, 0040, 0074, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 
  0155, 0145, 0075, 0042, 0155, 0145, 0163, 0163, 0141, 0147, 0145, 0137, 0164, 0171, 0160, 0145, 
  0042, 0076, 0107, 0124, 0113, 0137, 0115, 0105, 0123, 0123, 0101, 0107, 0105, 0137, 0117, 0124, 
  0110, 0105, 0122, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0076, 0012, 0040, 
  0040, 0040, 0040, 0074, 0143, 0150, 0151, 0154, 0144, 0040, 0151, 0156, 0164, 0145, 0162, 0156, 
  0141, 0154, 0055, 0143, 0150, 0151, 0154, 0144, 0075, 0042, 0166, 0142, 0157, 0170, 0042, 0076, 
  0012, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0157, 0142, 0152, 0145, 0143, 0164, 0040, 0143, 
  0154, 0141, 0163, 0163, 0075, 0042, 0107, 0164, 0153, 0102, 0157, 0170, 0042, 0040, 0151, 0144, 
  0075, 0042, 0144, 0151, 0141, 0154, 0157, 0147, 0055, 0166, 0142, 0157, 0170, 0061, 0042, 0076, 
  0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0160, 0162, 0157, 0160, 0145, 0162, 
  0164, 0171, 0040, 0156, 0141, 0155, 0145, 0075, 0042, 0143, 0141, 0156, 0137, 0146, 0157, 0143, 
  0165, 0163, 0042, 0076, 0106, 0141, 0154, 0163, 0145, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 
  0162, 0164, 0171, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0160, 0162, 
  0157, 0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 0155, 0145, 0075, 0042, 0157, 0162, 0151, 
  0145, 0156, 0164, 0141, 0164, 0151, 0157, 0156, 0042, 0076, 0166, 0145, 0162, 0164, 0151, 0143, 
  0141, 0154, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0076, 0012, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0074, 0143, 0150, 0151, 0154, 0144, 0040, 0151, 0156, 0164, 
  0145, 0162, 0156, 0141, 0154, 0055, 0143, 0150, 0151, 0154, 0144, 0075, 0042, 0141, 0143, 0164, 
  0151, 0157, 0156, 0137, 0141, 0162, 0145, 0141, 0042, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0074, 0157, 0142, 0152, 0145, 0143, 0164, 0040, 0143, 0154, 0141, 
  0163, 0163, 0075, 0042, 0107, 0164, 0153, 0102, 0165, 0164, 0164, 0157, 0156, 0102, 0157, 0170, 
  0042, 0040, 0151, 0144, 0075, 0042, 0144, 0151, 0141, 0154, 0157, 0147, 0055, 0141, 0143, 0164, 
  0151, 0157, 0156, 0137, 0141, 0162, 0145, 0141, 0042, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 
  0040, 0156, 0141, 0155, 0145, 0075, 0042, 0143, 0141, 0156, 0137, 0146, 0157, 0143, 0165, 0163, 
  0042, 0076, 0106, 0141, 0154, 0163, 0145, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 
  0171, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 
  0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 0155, 0145, 0075, 0042, 0150, 
  0145, 0170, 0160, 0141, 0156, 0144, 0042, 0076, 0124, 0162, 0165, 0145, 0074, 0057, 0160, 0162, 
  0157, 0160, 0145, 0162, 0164, 0171, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0074, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 
  0155, 0145, 0075, 0042, 0150, 0157, 0155, 0157, 0147, 0145, 0156, 0145, 0157, 0165, 0163, 0042, 
  0076, 0124, 0162, 0165, 0145, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0076, 
  0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0160, 0162, 
  0157, 0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 0155, 0145, 0075, 0042, 0154, 0141, 0171, 
  0157, 0165, 0164, 0137, 0163, 0164, 0171, 0154, 0145, 0042, 0076, 0145, 0170, 0160, 0141, 0156, 
  0144, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0076, 0012, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0143, 0150, 0151, 0154, 0144, 0076, 
  0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 
  0160, 0154, 0141, 0143, 0145, 0150, 0157, 0154, 0144, 0145, 0162, 0057, 0076, 0012, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0057, 0143, 0150, 0151, 0154, 
  0144, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 
  0143, 0150, 0151, 0154, 0144, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0074, 0160, 0154, 0141, 0143, 0145, 0150, 0157, 0154, 0144, 0145, 
  0162, 0057, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0074, 0057, 0143, 0150, 0151, 0154, 0144, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0040, 0074, 0057, 0157, 0142, 0152, 0145, 0143, 0164, 0076, 0012, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0160, 0141, 0143, 0153, 0151, 0156, 0147, 0076, 
  0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0160, 0162, 
  0157, 0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 0155, 0145, 0075, 0042, 0145, 0170, 0160, 
  0141, 0156, 0144, 0042, 0076, 0124, 0162, 0165, 0145, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 
  0162, 0164, 0171, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0074, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 0155, 0145, 0075, 
  0042, 0146, 0151, 0154, 0154, 0042, 0076, 0124, 0162, 0165, 0145, 0074, 0057, 0160, 0162, 0157, 
  0160, 0145, 0162, 0164, 0171, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0040, 0074, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 0155, 
  0145, 0075, 0042, 0160, 0157, 0163, 0151, 0164, 0151, 0157, 0156, 0042, 0076, 0060, 0074, 0057, 
  0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0074, 0057, 0160, 0141, 0143, 0153, 0151, 0156, 0147, 0076, 0012, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0057, 0143, 0150, 0151, 0154, 0144, 0076, 0012, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0143, 0150, 0151, 0154, 0144, 0076, 0012, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0157, 0142, 0152, 0145, 0143, 
  0164, 0040, 0143, 0154, 0141, 0163, 0163, 0075, 0042, 0107, 0164, 0153, 0102, 0157, 0170, 0042, 
  0040, 0151, 0144, 0075, 0042, 0142, 0157, 0170, 0042, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 
  0040, 0156, 0141, 0155, 0145, 0075, 0042, 0166, 0151, 0163, 0151, 0142, 0154, 0145, 0042, 0076, 
  0124, 0162, 0165, 0145, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0076, 0012, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0160, 0162, 0157, 
  0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 0155, 0145, 0075, 0042, 0143, 0141, 0156, 0137, 
  0146, 0157, 0143, 0165, 0163, 0042, 0076, 0106, 0141, 0154, 0163, 0145, 0074, 0057, 0160, 0162, 
  0157, 0160, 0145, 0162, 0164, 0171, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0074, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 
  0155, 0145, 0075, 0042, 0155, 0141, 0162, 0147, 0151, 0156, 0137, 0142, 0157, 0164, 0164, 0157, 
  0155, 0042, 0076, 0060, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0076, 0012, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0160, 0162, 0157, 
  0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 0155, 0145, 0075, 0042, 0155, 0141, 0162, 0147, 
  0151, 0156, 0137, 0162, 0151, 0147, 0150, 0164, 0042, 0076, 0066, 0074, 0057, 0160, 0162, 0157, 
  0160, 0145, 0162, 0164, 0171, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0040, 0074, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 0155, 
  0145, 0075, 0042, 0150, 0141, 0154, 0151, 0147, 0156, 0042, 0076, 0107, 0124, 0113, 0137, 0101, 
  0114, 0111, 0107, 0116, 0137, 0123, 0124, 0101, 0122, 0124, 0074, 0057, 0160, 0162, 0157, 0160, 
  0145, 0162, 0164, 0171, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0074, 0143, 0150, 0151, 0154, 0144, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0157, 0142, 0152, 0145, 0143, 0164, 0040, 
  0143, 0154, 0141, 0163, 0163, 0075, 0042, 0107, 0164, 0153, 0111, 0155, 0141, 0147, 0145, 0042, 
  0040, 0151, 0144, 0075, 0042, 0151, 0143, 0157, 0156, 0137, 0163, 0164, 0157, 0143, 0153, 0137, 
  0151, 0144, 0042, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0074, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0040, 0156, 
  0141, 0155, 0145, 0075, 0042, 0166, 0151, 0163, 0151, 0142, 0154, 0145, 0042, 0076, 0124, 0162, 
  0165, 0145, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0076, 0012, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0160, 
  0162, 0157, 0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 0155, 0145, 0075, 0042, 0143, 0141, 
  0156, 0137, 0146, 0157, 0143, 0165, 0163, 0042, 0076, 0106, 0141, 0154, 0163, 0145, 0074, 0057, 
  0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0160, 0162, 0157, 0160, 0145, 
  0162, 0164, 0171, 0040, 0156, 0141, 0155, 0145, 0075, 0042, 0170, 0160, 0141, 0144, 0042, 0076, 
  0062, 0064, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0076, 0012, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0160, 
  0162, 0157, 0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 0155, 0145, 0075, 0042, 0163, 0164, 
  0157, 0143, 0153, 0042, 0076, 0147, 0164, 0153, 0055, 0155, 0151, 0163, 0163, 0151, 0156, 0147, 
  0055, 0151, 0155, 0141, 0147, 0145, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 
  0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0074, 0057, 0157, 0142, 0152, 0145, 0143, 0164, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0160, 0141, 0143, 0153, 0151, 0156, 0147, 
  0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0074, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 0155, 0145, 
  0075, 0042, 0145, 0170, 0160, 0141, 0156, 0144, 0042, 0076, 0106, 0141, 0154, 0163, 0145, 0074, 
  0057, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0160, 0162, 0157, 0160, 
  0145, 0162, 0164, 0171, 0040, 0156, 0141, 0155, 0145, 0075, 0042, 0146, 0151, 0154, 0154, 0042, 
  0076, 0124, 0162, 0165, 0145, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0076, 
  0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0074, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 0155, 0145, 0075, 
  0042, 0160, 0157, 0163, 0151, 0164, 0151, 0157, 0156, 0042, 0076, 0060, 0074, 0057, 0160, 0162, 
  0157, 0160, 0145, 0162, 0164, 0171, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0074, 0057, 0160, 0141, 0143, 0153, 0151, 0156, 0147, 0076, 
  0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0057, 0143, 
  0150, 0151, 0154, 0144, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0074, 0143, 0150, 0151, 0154, 0144, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0157, 0142, 0152, 0145, 0143, 0164, 0040, 
  0143, 0154, 0141, 0163, 0163, 0075, 0042, 0107, 0164, 0153, 0102, 0157, 0170, 0042, 0040, 0151, 
  0144, 0075, 0042, 0154, 0141, 0142, 0145, 0154, 0055, 0142, 0157, 0170, 0042, 0076, 0012, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 
  0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 0155, 0145, 0075, 0042, 0166, 
  0151, 0163, 0151, 0142, 0154, 0145, 0042, 0076, 0124, 0162, 0165, 0145, 0074, 0057, 0160, 0162, 
  0157, 0160, 0145, 0162, 0164, 0171, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 
  0171, 0040, 0156, 0141, 0155, 0145, 0075, 0042, 0143, 0141, 0156, 0137, 0146, 0157, 0143, 0165, 
  0163, 0042, 0076, 0106, 0141, 0154, 0163, 0145, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 0162, 
  0164, 0171, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0074, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 
  0155, 0145, 0075, 0042, 0155, 0141, 0162, 0147, 0151, 0156, 0137, 0154, 0145, 0146, 0164, 0042, 
  0076, 0060, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0076, 0012, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0160, 
  0162, 0157, 0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 0155, 0145, 0075, 0042, 0155, 0141, 
  0162, 0147, 0151, 0156, 0137, 0162, 0151, 0147, 0150, 0164, 0042, 0076, 0060, 0074, 0057, 0160, 
  0162, 0157, 0160, 0145, 0162, 0164, 0171, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0160, 0162, 0157, 0160, 0145, 0162, 
  0164, 0171, 0040, 0156, 0141, 0155, 0145, 0075, 0042, 0155, 0141, 0162, 0147, 0151, 0156, 0137, 
  0164, 0157, 0160, 0042, 0076, 0060, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 
  0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0074, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 0155, 0145, 
  0075, 0042, 0155, 0141, 0162, 0147, 0151, 0156, 0137, 0142, 0157, 0164, 0164, 0157, 0155, 0042, 
  0076, 0060, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0076, 0012, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0160, 
  0162, 0157, 0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 0155, 0145, 0075, 0042, 0157, 0162, 
  0151, 0145, 0156, 0164, 0141, 0164, 0151, 0157, 0156, 0042, 0076, 0166, 0145, 0162, 0164, 0151, 
  0143, 0141, 0154, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0076, 0012, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 
  0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 0155, 0145, 0075, 0042, 0163, 
  0160, 0141, 0143, 0151, 0156, 0147, 0042, 0076, 0066, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 
  0162, 0164, 0171, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0074, 0143, 0150, 0151, 0154, 0144, 0076, 0012, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 
  0160, 0154, 0141, 0143, 0145, 0150, 0157, 0154, 0144, 0145, 0162, 0057, 0076, 0012, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0057, 
  0143, 0150, 0151, 0154, 0144, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0143, 0150, 0151, 0154, 0144, 0076, 0012, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0074, 0160, 0154, 0141, 0143, 0145, 0150, 0157, 0154, 0144, 0145, 0162, 0057, 0076, 0012, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0074, 0057, 0143, 0150, 0151, 0154, 0144, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0057, 0157, 0142, 0152, 0145, 0143, 0164, 0076, 
  0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 
  0160, 0141, 0143, 0153, 0151, 0156, 0147, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0160, 0162, 0157, 0160, 0145, 0162, 
  0164, 0171, 0040, 0156, 0141, 0155, 0145, 0075, 0042, 0145, 0170, 0160, 0141, 0156, 0144, 0042, 
  0076, 0124, 0162, 0165, 0145, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0076, 
  0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0074, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 0155, 0145, 0075, 
  0042, 0146, 0151, 0154, 0154, 0042, 0076, 0124, 0162, 0165, 0145, 0074, 0057, 0160, 0162, 0157, 
  0160, 0145, 0162, 0164, 0171, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 
  0040, 0156, 0141, 0155, 0145, 0075, 0042, 0160, 0141, 0144, 0144, 0151, 0156, 0147, 0042, 0076, 
  0060, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0076, 0012, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0160, 0162, 
  0157, 0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 0155, 0145, 0075, 0042, 0160, 0157, 0163, 
  0151, 0164, 0151, 0157, 0156, 0042, 0076, 0061, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 0162, 
  0164, 0171, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0074, 0057, 0160, 0141, 0143, 0153, 0151, 0156, 0147, 0076, 0012, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0057, 0143, 0150, 0151, 0154, 0144, 
  0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0057, 0157, 0142, 
  0152, 0145, 0143, 0164, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 
  0074, 0160, 0141, 0143, 0153, 0151, 0156, 0147, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0074, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0040, 
  0156, 0141, 0155, 0145, 0075, 0042, 0145, 0170, 0160, 0141, 0156, 0144, 0042, 0076, 0124, 0162, 
  0165, 0145, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0076, 0012, 0040, 0040, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0160, 0162, 0157, 0160, 0145, 
  0162, 0164, 0171, 0040, 0156, 0141, 0155, 0145, 0075, 0042, 0146, 0151, 0154, 0154, 0042, 0076, 
  0124, 0162, 0165, 0145, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 0076, 0012, 
  0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0160, 0162, 0157, 
  0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 0155, 0145, 0075, 0042, 0160, 0141, 0144, 0144, 
  0151, 0156, 0147, 0042, 0076, 0064, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0171, 
  0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 0160, 
  0162, 0157, 0160, 0145, 0162, 0164, 0171, 0040, 0156, 0141, 0155, 0145, 0075, 0042, 0160, 0157, 
  0163, 0151, 0164, 0151, 0157, 0156, 0042, 0076, 0061, 0074, 0057, 0160, 0162, 0157, 0160, 0145, 
  0162, 0164, 0171, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0040, 0074, 
  0057, 0160, 0141, 0143, 0153, 0151, 0156, 0147, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 0040, 
  0040, 0040, 0074, 0057, 0143, 0150, 0151, 0154, 0144, 0076, 0012, 0040, 0040, 0040, 0040, 0040, 
  0040, 0074, 0057, 0157, 0142, 0152, 0145, 0143, 0164, 0076, 0012, 0040, 0040, 0040, 0040, 0074, 
  0057, 0143, 0150, 0151, 0154, 0144, 0076, 0012, 0040, 0040, 0074, 0057, 0157, 0142, 0152, 0145, 
  0143, 0164, 0076, 0012, 0074, 0057, 0151, 0156, 0164, 0145, 0162, 0146, 0141, 0143, 0145, 0076, 
  0012, 0000, 0000, 0050, 0165, 0165, 0141, 0171, 0051
} };
#else /* _MSC_VER */
static const SECTION union { const guint8 data[3722]; const double alignment; void * const ptr;}  libxfce4ui_resource_data = {
  "\107\126\141\162\151\141\156\164\000\000\000\000\000\000\000\000"
  "\030\000\000\000\254\000\000\000\000\000\000\050\005\000\000\000"
  "\000\000\000\000\002\000\000\000\002\000\000\000\003\000\000\000"
  "\005\000\000\000\113\120\220\013\001\000\000\000\254\000\000\000"
  "\004\000\114\000\260\000\000\000\264\000\000\000\324\265\002\000"
  "\377\377\377\377\264\000\000\000\001\000\114\000\270\000\000\000"
  "\274\000\000\000\236\123\076\042\003\000\000\000\274\000\000\000"
  "\013\000\114\000\310\000\000\000\314\000\000\000\240\124\352\031"
  "\000\000\000\000\314\000\000\000\005\000\114\000\324\000\000\000"
  "\330\000\000\000\301\307\017\171\002\000\000\000\330\000\000\000"
  "\027\000\166\000\360\000\000\000\211\016\000\000\157\162\147\057"
  "\003\000\000\000\057\000\000\000\000\000\000\000\154\151\142\170"
  "\146\143\145\064\165\151\057\000\004\000\000\000\170\146\143\145"
  "\057\000\000\000\002\000\000\000\154\151\142\170\146\143\145\064"
  "\165\151\055\144\151\141\154\157\147\055\165\151\056\165\151\000"
  "\211\015\000\000\000\000\000\000\074\077\170\155\154\040\166\145"
  "\162\163\151\157\156\075\042\061\056\060\042\040\145\156\143\157"
  "\144\151\156\147\075\042\125\124\106\055\070\042\077\076\012\074"
  "\041\055\055\040\107\145\156\145\162\141\164\145\144\040\167\151"
  "\164\150\040\147\154\141\144\145\040\063\056\061\070\056\063\040"
  "\055\055\076\012\074\151\156\164\145\162\146\141\143\145\076\012"
  "\040\040\074\162\145\161\165\151\162\145\163\040\154\151\142\075"
  "\042\147\164\153\053\042\040\166\145\162\163\151\157\156\075\042"
  "\063\056\061\062\042\057\076\012\040\040\074\157\142\152\145\143"
  "\164\040\143\154\141\163\163\075\042\107\164\153\115\145\163\163"
  "\141\147\145\104\151\141\154\157\147\042\040\151\144\075\042\170"
  "\146\143\145\064\165\151\055\144\151\141\154\157\147\042\076\012"
  "\040\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141"
  "\155\145\075\042\143\141\156\137\146\157\143\165\163\042\076\106"
  "\141\154\163\145\074\057\160\162\157\160\145\162\164\171\076\012"
  "\040\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141"
  "\155\145\075\042\155\145\163\163\141\147\145\137\164\171\160\145"
  "\042\076\107\124\113\137\115\105\123\123\101\107\105\137\117\124"
  "\110\105\122\074\057\160\162\157\160\145\162\164\171\076\012\040"
  "\040\040\040\074\143\150\151\154\144\040\151\156\164\145\162\156"
  "\141\154\055\143\150\151\154\144\075\042\166\142\157\170\042\076"
  "\012\040\040\040\040\040\040\074\157\142\152\145\143\164\040\143"
  "\154\141\163\163\075\042\107\164\153\102\157\170\042\040\151\144"
  "\075\042\144\151\141\154\157\147\055\166\142\157\170\061\042\076"
  "\012\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\143\141\156\137\146\157\143"
  "\165\163\042\076\106\141\154\163\145\074\057\160\162\157\160\145"
  "\162\164\171\076\012\040\040\040\040\040\040\040\040\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\157\162\151"
  "\145\156\164\141\164\151\157\156\042\076\166\145\162\164\151\143"
  "\141\154\074\057\160\162\157\160\145\162\164\171\076\012\040\040"
  "\040\040\040\040\040\040\074\143\150\151\154\144\040\151\156\164"
  "\145\162\156\141\154\055\143\150\151\154\144\075\042\141\143\164"
  "\151\157\156\137\141\162\145\141\042\076\012\040\040\040\040\040"
  "\040\040\040\040\040\074\157\142\152\145\143\164\040\143\154\141"
  "\163\163\075\042\107\164\153\102\165\164\164\157\156\102\157\170"
  "\042\040\151\144\075\042\144\151\141\154\157\147\055\141\143\164"
  "\151\157\156\137\141\162\145\141\042\076\012\040\040\040\040\040"
  "\040\040\040\040\040\040\040\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\143\141\156\137\146\157\143\165\163"
  "\042\076\106\141\154\163\145\074\057\160\162\157\160\145\162\164"
  "\171\076\012\040\040\040\040\040\040\040\040\040\040\040\040\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\150"
  "\145\170\160\141\156\144\042\076\124\162\165\145\074\057\160\162"
  "\157\160\145\162\164\171\076\012\040\040\040\040\040\040\040\040"
  "\040\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141"
  "\155\145\075\042\150\157\155\157\147\145\156\145\157\165\163\042"
  "\076\124\162\165\145\074\057\160\162\157\160\145\162\164\171\076"
  "\012\040\040\040\040\040\040\040\040\040\040\040\040\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\154\141\171"
  "\157\165\164\137\163\164\171\154\145\042\076\145\170\160\141\156"
  "\144\074\057\160\162\157\160\145\162\164\171\076\012\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\143\150\151\154\144\076"
  "\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074"
  "\160\154\141\143\145\150\157\154\144\145\162\057\076\012\040\040"
  "\040\040\040\040\040\040\040\040\040\040\074\057\143\150\151\154"
  "\144\076\012\040\040\040\040\040\040\040\040\040\040\040\040\074"
  "\143\150\151\154\144\076\012\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\074\160\154\141\143\145\150\157\154\144\145"
  "\162\057\076\012\040\040\040\040\040\040\040\040\040\040\040\040"
  "\074\057\143\150\151\154\144\076\012\040\040\040\040\040\040\040"
  "\040\040\040\074\057\157\142\152\145\143\164\076\012\040\040\040"
  "\040\040\040\040\040\040\040\074\160\141\143\153\151\156\147\076"
  "\012\040\040\040\040\040\040\040\040\040\040\040\040\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\145\170\160"
  "\141\156\144\042\076\124\162\165\145\074\057\160\162\157\160\145"
  "\162\164\171\076\012\040\040\040\040\040\040\040\040\040\040\040"
  "\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\146\151\154\154\042\076\124\162\165\145\074\057\160\162\157"
  "\160\145\162\164\171\076\012\040\040\040\040\040\040\040\040\040"
  "\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\160\157\163\151\164\151\157\156\042\076\060\074\057"
  "\160\162\157\160\145\162\164\171\076\012\040\040\040\040\040\040"
  "\040\040\040\040\074\057\160\141\143\153\151\156\147\076\012\040"
  "\040\040\040\040\040\040\040\074\057\143\150\151\154\144\076\012"
  "\040\040\040\040\040\040\040\040\074\143\150\151\154\144\076\012"
  "\040\040\040\040\040\040\040\040\040\040\074\157\142\152\145\143"
  "\164\040\143\154\141\163\163\075\042\107\164\153\102\157\170\042"
  "\040\151\144\075\042\142\157\170\042\076\012\040\040\040\040\040"
  "\040\040\040\040\040\040\040\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\166\151\163\151\142\154\145\042\076"
  "\124\162\165\145\074\057\160\162\157\160\145\162\164\171\076\012"
  "\040\040\040\040\040\040\040\040\040\040\040\040\074\160\162\157"
  "\160\145\162\164\171\040\156\141\155\145\075\042\143\141\156\137"
  "\146\157\143\165\163\042\076\106\141\154\163\145\074\057\160\162"
  "\157\160\145\162\164\171\076\012\040\040\040\040\040\040\040\040"
  "\040\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141"
  "\155\145\075\042\155\141\162\147\151\156\137\142\157\164\164\157"
  "\155\042\076\060\074\057\160\162\157\160\145\162\164\171\076\012"
  "\040\040\040\040\040\040\040\040\040\040\040\040\074\160\162\157"
  "\160\145\162\164\171\040\156\141\155\145\075\042\155\141\162\147"
  "\151\156\137\162\151\147\150\164\042\076\066\074\057\160\162\157"
  "\160\145\162\164\171\076\012\040\040\040\040\040\040\040\040\040"
  "\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\150\141\154\151\147\156\042\076\107\124\113\137\101"
  "\114\111\107\116\137\123\124\101\122\124\074\057\160\162\157\160"
  "\145\162\164\171\076\012\040\040\040\040\040\040\040\040\040\040"
  "\040\040\074\143\150\151\154\144\076\012\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\074\157\142\152\145\143\164\040"
  "\143\154\141\163\163\075\042\107\164\153\111\155\141\147\145\042"
  "\040\151\144\075\042\151\143\157\156\137\163\164\157\143\153\137"
  "\151\144\042\076\012\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\074\160\162\157\160\145\162\164\171\040\156"
  "\141\155\145\075\042\166\151\163\151\142\154\145\042\076\124\162"
  "\165\145\074\057\160\162\157\160\145\162\164\171\076\012\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\143\141"
  "\156\137\146\157\143\165\163\042\076\106\141\154\163\145\074\057"
  "\160\162\157\160\145\162\164\171\076\012\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\170\160\141\144\042\076"
  "\062\064\074\057\160\162\157\160\145\162\164\171\076\012\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\163\164"
  "\157\143\153\042\076\147\164\153\055\155\151\163\163\151\156\147"
  "\055\151\155\141\147\145\074\057\160\162\157\160\145\162\164\171"
  "\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\074\057\157\142\152\145\143\164\076\012\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\074\160\141\143\153\151\156\147"
  "\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\145\170\160\141\156\144\042\076\106\141\154\163\145\074"
  "\057\160\162\157\160\145\162\164\171\076\012\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\074\160\162\157\160"
  "\145\162\164\171\040\156\141\155\145\075\042\146\151\154\154\042"
  "\076\124\162\165\145\074\057\160\162\157\160\145\162\164\171\076"
  "\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\160\157\163\151\164\151\157\156\042\076\060\074\057\160\162"
  "\157\160\145\162\164\171\076\012\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\074\057\160\141\143\153\151\156\147\076"
  "\012\040\040\040\040\040\040\040\040\040\040\040\040\074\057\143"
  "\150\151\154\144\076\012\040\040\040\040\040\040\040\040\040\040"
  "\040\040\074\143\150\151\154\144\076\012\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\074\157\142\152\145\143\164\040"
  "\143\154\141\163\163\075\042\107\164\153\102\157\170\042\040\151"
  "\144\075\042\154\141\142\145\154\055\142\157\170\042\076\012\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\166"
  "\151\163\151\142\154\145\042\076\124\162\165\145\074\057\160\162"
  "\157\160\145\162\164\171\076\012\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162\164"
  "\171\040\156\141\155\145\075\042\143\141\156\137\146\157\143\165"
  "\163\042\076\106\141\154\163\145\074\057\160\162\157\160\145\162"
  "\164\171\076\012\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141"
  "\155\145\075\042\155\141\162\147\151\156\137\154\145\146\164\042"
  "\076\060\074\057\160\162\157\160\145\162\164\171\076\012\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\155\141"
  "\162\147\151\156\137\162\151\147\150\164\042\076\060\074\057\160"
  "\162\157\160\145\162\164\171\076\012\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\155\141\162\147\151\156\137"
  "\164\157\160\042\076\060\074\057\160\162\157\160\145\162\164\171"
  "\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\155\141\162\147\151\156\137\142\157\164\164\157\155\042"
  "\076\060\074\057\160\162\157\160\145\162\164\171\076\012\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\157\162"
  "\151\145\156\164\141\164\151\157\156\042\076\166\145\162\164\151"
  "\143\141\154\074\057\160\162\157\160\145\162\164\171\076\012\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\163"
  "\160\141\143\151\156\147\042\076\066\074\057\160\162\157\160\145"
  "\162\164\171\076\012\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\074\143\150\151\154\144\076\012\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074"
  "\160\154\141\143\145\150\157\154\144\145\162\057\076\012\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074\057"
  "\143\150\151\154\144\076\012\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\074\143\150\151\154\144\076\012\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\074\160\154\141\143\145\150\157\154\144\145\162\057\076\012"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\074\057\143\150\151\154\144\076\012\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\074\057\157\142\152\145\143\164\076"
  "\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074"
  "\160\141\143\153\151\156\147\076\012\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\145\170\160\141\156\144\042"
  "\076\124\162\165\145\074\057\160\162\157\160\145\162\164\171\076"
  "\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\146\151\154\154\042\076\124\162\165\145\074\057\160\162\157"
  "\160\145\162\164\171\076\012\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\160\141\144\144\151\156\147\042\076"
  "\060\074\057\160\162\157\160\145\162\164\171\076\012\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\160\157\163"
  "\151\164\151\157\156\042\076\061\074\057\160\162\157\160\145\162"
  "\164\171\076\012\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\074\057\160\141\143\153\151\156\147\076\012\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\057\143\150\151\154\144"
  "\076\012\040\040\040\040\040\040\040\040\040\040\074\057\157\142"
  "\152\145\143\164\076\012\040\040\040\040\040\040\040\040\040\040"
  "\074\160\141\143\153\151\156\147\076\012\040\040\040\040\040\040"
  "\040\040\040\040\040\040\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\145\170\160\141\156\144\042\076\124\162"
  "\165\145\074\057\160\162\157\160\145\162\164\171\076\012\040\040"
  "\040\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\146\151\154\154\042\076"
  "\124\162\165\145\074\057\160\162\157\160\145\162\164\171\076\012"
  "\040\040\040\040\040\040\040\040\040\040\040\040\074\160\162\157"
  "\160\145\162\164\171\040\156\141\155\145\075\042\160\141\144\144"
  "\151\156\147\042\076\064\074\057\160\162\157\160\145\162\164\171"
  "\076\012\040\040\040\040\040\040\040\040\040\040\040\040\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\160\157"
  "\163\151\164\151\157\156\042\076\061\074\057\160\162\157\160\145"
  "\162\164\171\076\012\040\040\040\040\040\040\040\040\040\040\074"
  "\057\160\141\143\153\151\156\147\076\012\040\040\040\040\040\040"
  "\040\040\074\057\143\150\151\154\144\076\012\040\040\040\040\040"
  "\040\074\057\157\142\152\145\143\164\076\012\040\040\040\040\074"
  "\057\143\150\151\154\144\076\012\040\040\074\057\157\142\152\145"
  "\143\164\076\012\074\057\151\156\164\145\162\146\141\143\145\076"
  "\012\000\000\050\165\165\141\171\051" };
#endif /* !_MSC_VER */

static GStaticResource static_resource = { libxfce4ui_resource_data.data, sizeof (libxfce4ui_resource_data.data) - 1 /* nul terminator */, NULL, NULL, NULL };

G_GNUC_INTERNAL
GResource *libxfce4ui_get_resource (void);
GResource *libxfce4ui_get_resource (void)
{
  return g_static_resource_get_resource (&static_resource);
}
/*
  If G_HAS_CONSTRUCTORS is true then the compiler support *both* constructors and
  destructors, in a usable way, including e.g. on library unload. If not you're on
  your own.

  Some compilers need #pragma to handle this, which does not work with macros,
  so the way you need to use this is (for constructors):

  #ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
  #pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(my_constructor)
  #endif
  G_DEFINE_CONSTRUCTOR(my_constructor)
  static void my_constructor(void) {
   ...
  }

*/

#ifndef __GTK_DOC_IGNORE__

#if  __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 7)

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR(_func) static void __attribute__((constructor)) _func (void);
#define G_DEFINE_DESTRUCTOR(_func) static void __attribute__((destructor)) _func (void);

#elif defined (_MSC_VER) && (_MSC_VER >= 1500)
/* Visual studio 2008 and later has _Pragma */

#include <stdlib.h>

#define G_HAS_CONSTRUCTORS 1

/* We do some weird things to avoid the constructors being optimized
 * away on VS2015 if WholeProgramOptimization is enabled. First we
 * make a reference to the array from the wrapper to make sure its
 * references. Then we use a pragma to make sure the wrapper function
 * symbol is always included at the link stage. Also, the symbols
 * need to be extern (but not dllexport), even though they are not
 * really used from another object file.
 */

/* We need to account for differences between the mangling of symbols
 * for x86 and x64/ARM/ARM64 programs, as symbols on x86 are prefixed
 * with an underscore but symbols on x64/ARM/ARM64 are not.
 */
#ifdef _M_IX86
#define G_MSVC_SYMBOL_PREFIX "_"
#else
#define G_MSVC_SYMBOL_PREFIX ""
#endif

#define G_DEFINE_CONSTRUCTOR(_func) G_MSVC_CTOR (_func, G_MSVC_SYMBOL_PREFIX)
#define G_DEFINE_DESTRUCTOR(_func) G_MSVC_DTOR (_func, G_MSVC_SYMBOL_PREFIX)

#define G_MSVC_CTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _wrapper(void) { _func(); g_slist_find (NULL,  _array ## _func); return 0; } \
  __pragma(comment(linker,"/include:" _sym_prefix # _func "_wrapper")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _wrapper;

#define G_MSVC_DTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _constructor(void) { atexit (_func); g_slist_find (NULL,  _array ## _func); return 0; } \
   __pragma(comment(linker,"/include:" _sym_prefix # _func "_constructor")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _constructor;

#elif defined (_MSC_VER)

#define G_HAS_CONSTRUCTORS 1

/* Pre Visual studio 2008 must use #pragma section */
#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _wrapper(void) { _func(); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (*p)(void) = _func ## _wrapper;

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _constructor(void) { atexit (_func); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (* _array ## _func)(void) = _func ## _constructor;

#elif defined(__SUNPRO_C)

/* This is not tested, but i believe it should work, based on:
 * http://opensource.apple.com/source/OpenSSL098/OpenSSL098-35/src/fips/fips_premain.c
 */

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  init(_func)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void);

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  fini(_func)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void);

#else

/* constructors not supported for this compiler */

#endif

#endif /* __GTK_DOC_IGNORE__ */

#ifdef G_HAS_CONSTRUCTORS

#ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(libxfce4uiresource_constructor)
#endif
G_DEFINE_CONSTRUCTOR(libxfce4uiresource_constructor)
#ifdef G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(libxfce4uiresource_destructor)
#endif
G_DEFINE_DESTRUCTOR(libxfce4uiresource_destructor)

#else
#warning "Constructor not supported on this compiler, linking in resources will not work"
#endif

static void libxfce4uiresource_constructor (void)
{
  g_static_resource_init (&static_resource);
}

static void libxfce4uiresource_destructor (void)
{
  g_static_resource_fini (&static_resource);
}
